require "prefabutil"

local assets=
{
	Asset("ANIM", "anim/wardrobe.zip"),
	Asset("ANIM", "anim/ui_chest_4x4.zip"),
	Asset("ATLAS", "images/inventoryimages/wardrobe.xml")
	
}

local function onopen(inst)
    if not inst:HasTag("burnt") then
        inst.AnimState:PlayAnimation("open")
        inst.SoundEmitter:PlaySound("dontstarve/common/wardrobe_open")
    end
end 

local function onclose(inst)
    if not inst:HasTag("burnt") then
        if inst.AnimState:IsCurrentAnimation("open") then
            inst.AnimState:PlayAnimation("cancel")
            inst.SoundEmitter:PlaySound("dontstarve/common/wardrobe_close")
        end
    end
end

local function onhammered(inst, worker)
	if inst:HasTag("fire") and inst.components.burnable then
		inst.components.burnable:Extinguish()
	end
	inst.components.lootdropper:DropLoot()
	if 
		inst.components.container then inst.components.container:DropEverything() 
	end
	
	SpawnPrefab("collapse_big").Transform:SetPosition(inst.Transform:GetWorldPosition())
	inst.SoundEmitter:PlaySound("dontstarve/common/destroy_wood")
	inst:Remove()
end

local function onhit(inst, worker)
	inst.AnimState:PlayAnimation("hit")
	inst.AnimState:PushAnimation("closed", false)
	if inst.components.container then 
		inst.components.container:DropEverything() 
		inst.components.container:Close()
	end
end

local function onsave(inst, data)
	if inst:HasTag("burnt") or inst:HasTag("fire") then
        data.burnt = true
    end
end

local function onload(inst, data)
	if data and data.burnt then
        inst.components.burnable.onburnt(inst)
    end
end

local function onbuilt(inst)
	inst.AnimState:PlayAnimation("place")
	inst.AnimState:PushAnimation("closed")
	inst.SoundEmitter:PlaySound("dontstarve/common/wardrobe_craft")
end

local slotpos = {}
for y = 3, 0, -1 do
	for x = 0, 3 do
		table.insert(slotpos, Vector3(80*x-80*2+40, 80*y-80*2+40,0))
	end
end

local function itemtest(inst, item, slot)
	return (item.components.equippable) or 
	item.prefab == "sewing_kit" or 
	item.prefab == "fabric"
end

local function fn(Sim)
	local inst = CreateEntity()
    inst.entity:AddTransform()
	inst.entity:AddAnimState()
	inst.entity:AddSoundEmitter()

    MakeObstaclePhysics(inst, 1.2)    

local minimap = inst.entity:AddMiniMapEntity()	
	minimap:SetIcon("wardrobe.tex")
	inst:AddTag("structure")
	inst:AddTag("chest")
    inst.AnimState:SetBank("wardrobe")
    inst.AnimState:SetBuild("wardrobe")
    inst.AnimState:PlayAnimation("close")
	
	MakeMediumBurnable(inst, nil, nil, true)
	MakeLargePropagator(inst)
	
    inst.AnimState:SetBank("wardrobe")
    inst.AnimState:SetBuild("wardrobe")
    inst.AnimState:PlayAnimation("closed", true)
    
    inst:AddComponent("inspectable")
    inst:AddComponent("container")
	inst.components.container.itemtestfn = itemtest
    inst.components.container:SetNumSlots(#slotpos)
	
    inst.components.container.onopenfn = onopen
    inst.components.container.onclosefn = onclose
	
    inst.components.container.widgetslotpos = slotpos
    inst.components.container.numslots = #slotpos
	inst.components.container.widgetanimbank = "ui_chest_4x4"
    inst.components.container.widgetanimbuild = "ui_chest_4x4"	
    inst.components.container.widgetpos = Vector3(0,200,0)
	inst.components.container.side_align_tip = 160

    inst:AddComponent("lootdropper")

    inst:AddComponent("workable")
    inst.components.workable:SetWorkAction(ACTIONS.HAMMER)
    inst.components.workable:SetWorkLeft(3)
    inst.components.workable:SetOnFinishCallback(onhammered)
    inst.components.workable:SetOnWorkCallback(onhit) 
	
	inst:ListenForEvent( "onbuilt", onbuilt)
	MakeSnowCovered(inst, .01)	

    return inst
end

return Prefab( "common/wardrobe", fn, assets),
	MakePlacer("common/wardrobe_placer", "wardrobe", "wardrobe", "closed") 

